import requests
import configparser
from seclook.find_config import find_config

config_path = find_config()
config = configparser.ConfigParser()
config.read(config_path)

virustotal_api_key = config["virustotal"]["api_key"]

base_url = "https://www.virustotal.com/api/v3/search"


def search(value):
    headers = {"x-apikey": virustotal_api_key}
    params = {"query": value}
    response = requests.get(base_url, headers=headers, params=params)
    return response.json()



import requests
import configparser
from seclook.find_config import find_config

config_path = find_config()
config = configparser.ConfigParser()
config.read(config_path)

shodan_api_key = config["shodan"]["api_key"]

base_url = "https://api.shodan.io/shodan/host/{}"


def search(value):
    headers = {"Accept": "application/json"}
    response = requests.get(
        base_url.format(value), headers=headers, params={"key": shodan_api_key}
    )
    return response.json()



from setuptools import setup, find_packages

setup(
    name="seclook",
    version="0.1.3",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "click",
        "requests",
        "configparser",
    ],
    entry_points={
        "console_scripts": [
            "seclook=seclook.cli:main",
        ],
    },
    description="Simple security lookups via CLI",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/ackatz/seclook",
)



import os


def find_config():
    # List of directories to look in
    dirs_to_check = [
        os.getcwd(),  # Current working directory
        os.path.dirname(os.path.abspath(__file__)),  # Directory of this script
        os.path.join(
            os.path.expanduser("~"), ".seclook"
        ),  # A .seclook directory in the user's home directory
    ]

    for dir in dirs_to_check:
        config_path = os.path.join(dir, "config.ini")
        if os.path.exists(config_path):
            return config_path

    raise FileNotFoundError(
        "No config.ini file found in any of the checked directories"
    )



import requests
import configparser
from seclook.find_config import find_config

config_path = find_config()
config = configparser.ConfigParser()
config.read(config_path)

emailrep_api_key = config["emailrep"]["api_key"]

base_url = "https://emailrep.io/{}"


def search(value):
    headers = {"Key": emailrep_api_key}
    response = requests.get(base_url.format(value), headers=headers)
    return response.json()



#!/usr/bin/env python3

import click
from seclook.lookups import shodan_lookup, virustotal_lookup, emailrep_lookup
import json
import os


@click.command()
@click.argument("service")
@click.argument("value")
@click.option(
    "--export", is_flag=True, help="Export results to a JSON file on the desktop"
)
def main(service, value, export):
    """Perform lookups from various security services"""

    result = None

    if service.lower() == "shodan":
        result = shodan_lookup.search(value)
    elif service.lower() == "virustotal":
        result = virustotal_lookup.search(value)
    elif service.lower() == "emailrep":
        result = emailrep_lookup.search(value)
    else:
        click.echo("Unknown service")
        return

    # If export flag is set, save to a JSON file on the desktop
    if export:
        desktop = os.path.join(os.path.expanduser("~"), "Desktop")
        filename = os.path.join(desktop, f"seclook_{service}_{value}.json")

        with open(filename, "w") as outfile:
            json.dump(result, outfile, indent=4)

        click.echo(f"Results exported to {filename}")
        return

    # Pretty print the result
    pretty_result = json.dumps(result, indent=4)
    click.echo(pretty_result)


if __name__ == "__main__":
    main()
